@@ -13,6 +13,8 @@
 
 package com.openexchange.documentconverter;
 
+import java.net.URL;
+
 //-------------------
 //- CacheDescriptor -
 //-------------------
@@ -51,4 +53,9 @@ public class CacheDescriptor {
      * the timeout in milliseconds for the cached objects to be removed; 0 to disable the timeout based removal of cached objects
      */
     public long timeoutMilliseconds = 0;
+
+    /**
+     * the timeout in milliseconds for the cached objects to be removed; 0 to disable the timeout based removal of cached objects
+     */
+    public URL[] remoteCacheUrls = null;
 }
