@@ -47,6 +47,13 @@ public class Config {
      */
     public URL ENGINE_REMOTE_BASEURL = null;
 
+    /**
+     * Cache URL(s) to be used for remote conversions;
+     * the local backend will handle caching in every case, but a cache
+     * speedup can be achieved by adding additional cache servers
+     */
+    public URL[] ENGINE_REMOTE_CACHEURLS = null;
+
     /**
      * the location of the log
      */
