@@ -37,16 +37,16 @@ public interface IJobProcessor {
      *
      * @param serverJob The server job to be added to the queue
      * @param jobStatusListener The listener associated with the given server job
-     * @return The unique id of the added job or 0 in case of failure
+     * @return The unique id string of the added job or null in case of failure
      */
-    long addJob(IJob serverJob, JobPriority jobPriority, IJobStatusListener jobStatusListener);
+    String addJob(IJob serverJob, JobPriority jobPriority, IJobStatusListener jobStatusListener);
 
     /**
      * Removes the Job with the given id from the queue of Jobs
      *
-     * @param jobId
+     * @param jobIdStr
      */
-    void removeJob(long jobId);
+    void removeJob(String jobIdStr);
 
     /**
      * Adds a listener for global JobStatus change events
@@ -65,10 +65,10 @@ public interface IJobProcessor {
     /**
      * Returns the current status of the Job with the given id
      *
-     * @param jobId
+     * @param jobIdStr
      * @return the current status of the Job
      */
-    JobStatus getJobStatus(long jobId);
+    JobStatus getJobStatus(String jobIdStr);
 
     /**
      * terminates the JobProcessor
