@@ -30,7 +30,7 @@ public interface IManager {
 
     /**
      * @param backendDescriptors the array of engine descriptors, containing the properties of each single backend engine
-     * @param cacheDescriptor contains properties to setup a JobCache
+     * @param cacheDescriptor contains properties to setup a cache
      * @return the JobProcessor to execute single jobs or null in case of failure
      */
     public IJobProcessor init(BackendDescriptor backendDescriptors[], CacheDescriptor cacheDescriptor);
@@ -51,6 +51,11 @@ public interface IManager {
      */
     IJobProcessor getJobProcessor();
 
+    /**
+     * @return The used converter cache or null if none is used
+     */
+    ICache getCache();
+
     /**
      * @param jobType the export format for the conversion
      * @param jobProperties contains additional properties to customize the job
@@ -111,12 +116,13 @@ public interface IManager {
      * @param targetMimeType The target mime type of the rasterized SVG image; currently support are image/png and image/jpeg [in/out]
      * @param targetWidth The target width in pixels of the rasterized SVG image [in/out]
      * @param targetHeight The target height in pixels of the rasterized SVG image [in/out]
-     * @param preserveAspectRatio Use the given targetWidth and targetHeight as bounding rectangle to fit the image extents, preserving the default aspect ratio
+     * @param scaleType Set to 'none', 'contain' or 'cover'. With 'contain' set, use the given targetWidth and targetHeight as bounding rectangle
+     *        to fit the image extents, preserving the default aspect ratio. 'cover' behaves like 'contain', but prevents any upscaling of the image extents
      * @param targetZoomFactor The zoom factor to apply for the rasterized SVG image;
      *        the zoom factor is applied after any extent set by target width and target height
      * @return The stream the rasterized SVG image can be read from or null in case of a failure
      */
-    public InputStream convertSVG(InputStream svgInputStm, String[] targetMimeType, int[] targetPixelWidth, int[] targetPixelHeight, boolean preserveDefaultAspectRatio, float targetZoomFactor);
+    public InputStream convertSVG(InputStream svgInputStm, String[] targetMimeType, int[] targetPixelWidth, int[] targetPixelHeight, String scaleType, float targetZoomFactor);
 
 
     /**
