@@ -29,5 +29,6 @@ public enum JobStatus {
     READY,
     RUNNING,
     FINISHED,
-    ERROR
+    ERROR,
+    REMOVED
 }
